==> lametric-1.0.0.tar.gz: lametric/src/Service/LaMetricNotification.php <==
<?php

namespace Drupal\lametric\Service;

use Drupal\Component\Serialization\SerializationInterface;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\RequestOptions;

/**
 * Class LaMetricNotification.
 */
class LaMetricNotification implements LaMetricNotificationInterface {

  /**
   * A guzzle http client instance.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The JSON serialization.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $jsonSerialization;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    ClientInterface $http_client,
    SerializationInterface $json_serialization
  ) {
    $this->httpClient = $http_client;
    $this->jsonSerialization = $json_serialization;
  }

  /**
   * {@inheritdoc}
   */
  public function sendLocally($ip, $key, $text, $icon = NULL) {
    try {
      $request = $this->httpClient->post(
        sprintf('http://%s:8080/api/v2/device/notifications', $ip),
        [
          RequestOptions::AUTH => ['dev', $key],
          RequestOptions::JSON => ['model' => $this->frames($text, $icon)],
        ]
      );

      $response = $request->getBody()->getContents();
      $content = $this->jsonSerialization->decode($response);

      if (
        isset($content['success']) &&
        is_array($content['success']) &&
        isset($content['success']['id']) &&
        is_numeric($content['success']['id'])
      ) {
        return (int) $content['success']['id'];
      }
    }
    catch (\Exception $exception) {
      return $exception;
    }

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function sendApplication($url, $token, $text, $icon = NULL) {
    try {
      $this->httpClient->post(self::PUSH_URL_PREFIX . $url, [
        RequestOptions::HEADERS => [
          'X-Access-Token' => $token . self::API_TOKEN_SUFFIX,
          'Cache-Control' => 'no-cache',
        ],
        RequestOptions::JSON => $this->frames($text, $icon),
      ]);
    }
    catch (\Exception $exception) {
      return $exception;
    }

    return TRUE;
  }

  /**
   * Prepare the structure of frames.
   *
   * @param string $text
   *   The message text.
   * @param int|null $icon
   *   (optional) The icon ID. Defaults to NULL.
   *
   * @return array
   *   The frames.
   */
  protected function frames($text, $icon = NULL) {
    $frame = ['text' => $text];

    if ($icon !== NULL) {
      $frame['icon'] = $icon;
    }

    return ['frames' => [$frame]];
  }

}

==> lametric-1.0.1.tar.gz: lametric/src/Service/LaMetricNotification.php <==
<?php

namespace Drupal\lametric\Service;

use Drupal\Component\Serialization\SerializationInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\RequestOptions;

/**
 * Class LaMetricNotification.
 */
class LaMetricNotification implements LaMetricNotificationInterface {

  /**
   * A guzzle http client instance.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The JSON serialization.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $jsonSerialization;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    ClientInterface $http_client,
    SerializationInterface $json_serialization,
    ConfigFactoryInterface $config_factory
  ) {
    $this->httpClient = $http_client;
    $this->jsonSerialization = $json_serialization;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public function send($text, $icon = NULL) {
    $config = $this->configFactory->get('lametric.settings');

    if ($config->get('local')) {
      $type = 'local';
      $method = 'sendLocally';
    }
    else {
      $type = 'app';
      $method = 'sendApplication';
    }

    return $this->$method(
      $config->get("types.$type.url"),
      $config->get("types.$type.key"),
      $text,
      $icon
    );
  }

  /**
   * {@inheritdoc}
   */
  public function sendLocally($ip, $key, $text, $icon = NULL) {
    try {
      $request = $this->httpClient->post(
        sprintf('http://%s:8080/api/v2/device/notifications', $ip),
        [
          RequestOptions::AUTH => ['dev', $key],
          RequestOptions::JSON => ['model' => $this->frames($text, $icon)],
        ]
      );

      $response = $request->getBody()->getContents();
      $content = $this->jsonSerialization->decode($response);

      if (
        isset($content['success']) &&
        is_array($content['success']) &&
        isset($content['success']['id']) &&
        is_numeric($content['success']['id'])
      ) {
        return (int) $content['success']['id'];
      }
    }
    catch (\Exception $exception) {
      return $exception;
    }

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function sendApplication($url, $token, $text, $icon = NULL) {
    try {
      $this->httpClient->post(self::PUSH_URL_PREFIX . $url, [
        RequestOptions::HEADERS => [
          'X-Access-Token' => $token . self::API_TOKEN_SUFFIX,
          'Cache-Control' => 'no-cache',
        ],
        RequestOptions::JSON => $this->frames($text, $icon),
      ]);
    }
    catch (\Exception $exception) {
      return $exception;
    }

    return TRUE;
  }

  /**
   * Prepare the structure of frames.
   *
   * @param string $text
   *   The message text.
   * @param int|null $icon
   *   (optional) The icon ID. Defaults to NULL.
   *
   * @return array
   *   The frames.
   */
  protected function frames($text, $icon = NULL) {
    $frame = ['text' => $text];

    if ($icon !== NULL) {
      $frame['icon'] = $icon;
    }

    return ['frames' => [$frame]];
  }

}
